package de.hawhamburg.reachability.ui.frame.resource;

import de.hawhamburg.reachability.ui.enumeration.FieldType;

/**
 * Data object which describes the attributes of an {@link DisplayParameter}.<br><br>
 * 
 * An Objects of this class holds the information necessary for the display of changeable parameters in user interfaces.
 *
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR}
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public class DisplayParameter {
    
    /**
     * The parameters name as {@link String}.
     */
    private String name;
    
    /**
     * The text which shall be displayed to the user as name as {@link String}.
     */
    private String display;
    
    /**
     * The {@link FieldType} which describes how the user may manipulate the value of this parameter.
     */
    private FieldType fieldType;
    
    /**
     * The default value for this parameter as {@link String}.
     */
    private String defaultValue;
    
    /**
     * Initializes a new {@link DisplayParameter} object.
     *
     * @param nameIn            The parameters name as {@link String}.
     * @param displayIn         The text that shall be displayed to the user as parameters name as {@link String}.
     * @param fieldTypeIn       The {@link FieldType} which describes how the user may manipulate the value of this 
     *                          parameter.
     * @param defaultValueIn    The default value of this parameter as {@link String}.
     */
    public DisplayParameter(final String nameIn,
                            final String displayIn,
                            final FieldType fieldTypeIn,
                            final String defaultValueIn) {
        this.name           = nameIn;
        this.display        = displayIn;
        this.fieldType      = fieldTypeIn;
        this.defaultValue   = defaultValueIn;
    }
    
    /**
     * Returns the parameters name as {@link String}.
     * 
     * @return                  The parameters name as {@link String}.
     */
    public final String getName() {
        return name;
    }
    
    /**
     * Returns the parameters display name as {@link String}.
     * 
     * @return                  The parameters display name as {@link String}.
     */
    public final String getDisplay() {
        return display;
    }
    
    /**
     * Returns the parameters field type as {@link FieldType}.
     * 
     * @return                  The parameters field type as {@link FieldType}.
     */
    public final FieldType getFieldType() {
        return fieldType;
    }
    
    /**
     * Returns the parameters default value as {@link String}.
     * 
     * @return                  The parameters default name as {@link String}.
     */
    public final String getDefaultValue() {
        return defaultValue;
    }
}
