package de.hawhamburg.reachability;

/**
 * Objects of classes which implements this interface can be stopped by using {@link #shutDown()}. This method shall
 * ensure, that all opened connections will be closed and all started threads shut down as well. To determine if the 
 * object has been shut down, the method {@link #isActive()} may be called.
 *
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR}
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public interface StopableObject {
    
    /**
     * Determines whether the method {@link #shutDown()} has been called on this object or not.
     *
     * @return  <code>true</code> if the object has been shut down, otherwise <code>false</code>.
     */
    boolean isActive();

    /**
     * Shuts the object down. The method shall ensure, that all opened or started resources (e.g. ActiveMQ connections, 
     * started threads) will be controlled shut down before the objects ends itself.
     */
    void shutDown();
}
