package de.hawhamburg.reachability.json;

import java.util.Map;

import de.hawhamburg.lifecycle.data.JsonLPObject;
import de.hawhamburg.reachability.enumeration.ReachabilityGroup;
import de.hawhamburg.reachability.enumeration.ReachabilityStatus;

/**
 * Basic reachability information message representing the format in which the results of the reachability agent will be
 * propagated via the ActiveMQ.<br><br> 
 * 
 * This class represents the structure of the JSON messages which describes a reachability information of this 
 * reachability agent. This messages are output informations and shall be interpreted by other livingplace agents like a
 * telecommunication agent or stress companion.
 * 
 * One of this messages will be send to the ActiveMQ for each iteration of the reasoner and contain for each value in 
 * the {@link ReachabilityGroup} enumeration its current state of reachability (on value of {@link ReachabilityStatus}).
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public class JsonReachabilityInformation extends JsonLPObject {

    /**
     * The current {@link ReachabilityStatus} to each {@link ReachabilityGroup} as {@link Map}.
     */
    public Map<ReachabilityGroup, ReachabilityStatus> currentStatus;
    
    /**
     * Some textual remark (not further specified in this version).
     */
    public String Remark;
    
    /**
     * Public default constructor to create a new instance of this class.
     */
    public JsonReachabilityInformation() { }
}
